/*
 * Copyright (c) 2008 Graham Booker
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

/*This is used if the punctuation shoud be stored separately.  It provides some additional compression when done.*/
#define SPLIT_OFF_PUNCTUATION

#ifdef SPLIT_OFF_PUNCTUATION
extern NSString *punctBefore;
extern NSString *punctAfter;
#endif //SPLIT_OFF_PUNCTUATION

/*Store numbers in LITTLE ENDIAN.  This has no preformance loss at all on a little endian machine*/
#ifdef __LITTLE_ENDIAN__
#define swab32(x) (x)
#define swab16(x) (x)
#else
#if defined (__i386__)
static inline uint32_t swab32(uint32_t x)
{
	__asm__("bswap %0" : "=r" (x) : "0" (x));
	return x;
}
static inline uint16_t swab16(uint16_t x)
{
	__asm__("xchg %%al, %%ah" : "=a" (x) : "a" (x));
	return x;
}
#else
static inline u_int32_t swab32(u_int32_t big)
{
	u_int32_t tmp = ((big & 0xff00ff00) >> 8) | ((big & 0x00ff00ff) << 8);
	return (tmp >> 16) | (tmp << 16);
}
static inline u_int16_t swab16(u_int16_t big)
{
	u_int16_t tmp = ((big & 0xff00) >> 8) | ((big & 0x00ff) << 8);
	return tmp;
}
#endif
#endif

/*!
 * Get an little endian 32-bit integere stored in data at a given offset
 * @param inData The data to read
 * @param offset The offset within inData to read
 * @return The 32-bit little endian number converted to native endian at offset within inData.
 */
static inline unsigned int getCountAtOffset(NSData *inData, unsigned int offset)
{
	unsigned int count;
	[inData getBytes:&count range:NSMakeRange(offset, sizeof(unsigned int))];
#ifndef __LITTLE_ENDIAN__
	count = swab32(count);
#endif
	return count;
}
