/*
 * Copyright (c) 2008 Graham Booker
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#import <Cocoa/Cocoa.h>

@interface NSData (Extensions)
/*!
 * Create an gzip compressed data block within an NSData object from bytes and a length
 *
 * @param bytes The bytes to compress
 * @param length The number of bytes to compress
 * @param An NSData object containing a uncompressed length and gzip compressed bitstream of bytes
 */
+ (NSData *)gzipCompressedBlockWithBytes:(const unsigned char *)bytes length:(unsigned long)length;
/*!
 * Create a gunzip version of the compressed NSData
 *
 * @return The gunzip data stored in self
 */
- (NSData *)gunzipCompressedBlock;
@end
