/*
 * Copyright (c) 2008 Graham Booker
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#import "NSData_Extensions.h"

#include <zlib.h>
#import "CompressorCommon.h"

@implementation NSData (Extensions)
+ (NSData *)gzipCompressedBlockWithBytes:(const unsigned char *)bytes length:(unsigned long)length
{
	//Create the resulting data
	unsigned long compSize = compressBound(length);
	NSMutableData *data = [[NSMutableData alloc] initWithLength:compSize+sizeof(unsigned int)];
	//Compress
	compress2([data mutableBytes]+sizeof(unsigned int), &compSize, bytes, length, Z_BEST_COMPRESSION);
	unsigned int uncompLen = swab32(length);
	//Store the uncompressed size
	[data replaceBytesInRange:NSMakeRange(0, sizeof(unsigned int)) withBytes:&uncompLen length:sizeof(unsigned int)];
	[data setLength:compSize+sizeof(unsigned int)];
	return [data autorelease];
}

- (NSData *)gunzipCompressedBlock
{
	//Get the uncopmressed size
	unsigned int size = getCountAtOffset(self, 0);
	unsigned long unCompSize = size;
	NSMutableData *uncompData = [[NSMutableData alloc] initWithLength:unCompSize];
	//Decompress
	uncompress([uncompData mutableBytes], &unCompSize, [self bytes]+sizeof(unsigned long), [self length] - sizeof(unsigned long));
	return [uncompData autorelease];
}
@end
